@@ -1,4 +1,6 @@
 library(biomaRt)
+cache <- file.path(tempdir(), "biomart_cache_test")
+Sys.setenv(BIOMART_CACHE = cache)
 
 context("useMart() functionality")
 
@@ -7,7 +9,7 @@ ensembl <- useMart("ensembl")
 ensembl_with_dataset <- useDataset(ensembl, 
                                    dataset = "xtropicalis_gene_ensembl")
 
-test_that("Show give sensible dataset information", {
+test_that("Show gives sensible dataset information", {
     expect_output(object = show(ensembl), 
                   regexp = "No dataset selected")
     expect_output(object = show(ensembl_with_dataset), 
