@@ -1,4 +1,6 @@
 library(biomaRt)
+cache <- file.path(tempdir(), "biomart_cache_test")
+Sys.setenv(BIOMART_CACHE = cache)
 
 context("Result caching")
 
@@ -7,7 +9,7 @@ chrom <- c(17,20,"Y")
 attributes <- "hgnc_symbol"
 filters <- c("go","chromosome_name")
 values <- list(go, chrom)
-ensembl <- useEnsembl("ensembl", "hsapiens_gene_ensembl", mirror = "uswest")
+ensembl <- useEnsembl("ensembl", "hsapiens_gene_ensembl", mirror = "www")
 
 test_that("Hashing is order insensitive", {
    expect_identical(
@@ -16,17 +18,22 @@ test_that("Hashing is order insensitive", {
    )
 })
 
+test_that("Environment variable for cache location is used", {
+    expect_message(biomartCacheInfo(),
+                   regexp = "biomart_cache_test")
+})
+
 test_that("We find cache for previous query", {
     
-    mart <- useMart(biomart = "ensembl",
-                    host = "https://useast.ensembl.org",
-                    dataset ="mmusculus_gene_ensembl",
-                    port = 443)
+    mart <- useEnsembl(biomart = "ensembl", 
+                       mirror = "useast", 
+                       dataset ="mmusculus_gene_ensembl")
     
     expect_message(res <- getBM(filter = "ensembl_gene_id",
                  values = "ENSMUSG00000028798",
                  attributes = c("ensembl_transcript_id", "neugenii_homolog_canonical_transcript_protein"),
-                 mart = mart),  
+                 mart = mart,
+                 verbose = TRUE),  
                  regexp = "Cache found")
 })
 
@@ -36,7 +43,7 @@ test_that("Cache details are printed", {
 })
 
 test_that("Cache can be cleared", {
-    cache_file <- rappdirs::user_cache_dir(appname = "biomaRt")
+    cache_file <- biomartCacheInfo()
     expect_true( file.exists( cache_file ) )
     expect_silent( biomaRt:::biomartCacheClear() )
     expect_false( file.exists( cache_file) )
